@@ -5,7 +5,7 @@ import pytest
 import shutil
 import icecream
 from learning_loop_node.globals import GLOBALS
-
+import os
 icecream.install()
 logging.basicConfig(level=logging.DEBUG)
 
@@ -21,12 +21,17 @@ def create_project():
     test_helper.LiveServerSession().delete(f"/api/zauberzeug/projects/pytest?keep_images=true")
 
 
-@pytest.fixture(autouse=True, scope='function')
-def data_folder():
-    GLOBALS.data_folder = '/tmp/learning_loop_lib_data'
-    shutil.rmtree(GLOBALS.data_folder, ignore_errors=True)
+@pytest.fixture(autouse=True, scope='session')
+def clea_loggers():
     yield
-    shutil.rmtree(GLOBALS.data_folder, ignore_errors=True)
+    # see https://github.com/pytest-dev/pytest/issues/5502
+    """Remove handlers from all loggers"""
+    import logging
+    loggers = [logging.getLogger()] + list(logging.Logger.manager.loggerDict.values())
+    for logger in loggers:
+        handlers = getattr(logger, 'handlers', [])
+        for handler in handlers:
+            logger.removeHandler(handler)
 
 
 @pytest.fixture(autouse=True, scope='function')
@@ -34,3 +39,12 @@ def loop_session():
     loop.session = None
     yield
     loop.session = None
+
+
+@pytest.fixture(autouse=True, scope='function')
+def data_folder():
+    GLOBALS.data_folder = '/tmp/learning_loop_lib_data'
+    shutil.rmtree(GLOBALS.data_folder, ignore_errors=True)
+    os.makedirs(GLOBALS.data_folder, exist_ok=True)
+    yield
+    shutil.rmtree(GLOBALS.data_folder, ignore_errors=True)
