@@ -30,7 +30,7 @@ async def download_images_data(organization: str, project: str, image_ids: List[
     jepeg_check_info()
     images_data = []
     starttime = time.time()
-    for i in tqdm(range(0, len(image_ids), chunk_size)):
+    for i in tqdm(range(0, len(image_ids), chunk_size), position=0, leave=True):
         chunk_ids = image_ids[i:i+chunk_size]
         async with loop.get(f'api/{organization}/projects/{project}/images?ids={",".join(chunk_ids)}') as response:
             if response.status != 200:
@@ -39,7 +39,7 @@ async def download_images_data(organization: str, project: str, image_ids: List[
                 continue
             images_data += (await response.json())['images']
             total_time = round(time.time() - starttime, 1)
-            if(images_data):
+            if (images_data):
                 per100 = total_time / len(images_data) * 100
                 logging.debug(f'[+] Performance: {total_time} sec total. Per 100 : {per100:.1f} sec')
             else:
@@ -54,7 +54,7 @@ async def download_images(paths: List[str], image_ids: List[str], image_folder:
     logging.info('fetching image files')
     starttime = time.time()
     os.makedirs(image_folder, exist_ok=True)
-    for i in tqdm(range(0, len(image_ids), chunk_size)):
+    for i in tqdm(range(0, len(image_ids), chunk_size), position=0, leave=True):
         chunk_paths = paths[i:i+chunk_size]
         chunk_ids = image_ids[i:i+chunk_size]
         tasks = []
@@ -129,7 +129,7 @@ async def download_model(target_folder: str, context: Context, model_id: str, fo
     created_files = []
     files = glob(f'{tmp_path}/**/*', recursive=True)
     for file in files:
-        logging.debug(f'moving model file {os.path.basename(file)} to training folder.')
         new_file = shutil.move(file, target_folder)
+        logging.info(f'moved model file {os.path.basename(file)} to {new_file}.')
         created_files.append(new_file)
     return created_files
